Dijit RadioButton checked state test

Native input[type=radio] Test

Click the radio buttons and view the console output.

Native radio 1
Native radio 2
Native radio 3
Dijit/form/RadioButton Test

Click the radio buttons and view the console output.

Dijit RadioButton 1
Dijit RadioButton 2
Dijit RadioButton 3

Expectation: only a single radio button can be checked at a time

Result: two radio buttons are simultaneously checked

When the click handler is called, the "checked" property should be set true, but if the event handler calls preventDefault(), then after a delay, the "checked" property will revert to false.

Call evt.preventDefault() on click: